@@ -127,6 +127,10 @@ body using the boundary BOUNDARY."
       (crlf))))
 
 (defun %read-body (stream element-type)
+  ;; On ABCL, a flexi-stream is not a normal stream. This is caused by
+  ;; a bug in ABCL which is supposedly quite difficult to fix. More
+  ;; details here: http://abcl.org/trac/ticket/377
+  #-abcl
   (declare (stream stream))
   "Helper function to read from stream into a buffer of element-type, which is returned."
   (let ((buffer (make-array +buffer-size+ :element-type element-type))
@@ -374,7 +378,7 @@ If PROXY is not NIL, it should be a string denoting a proxy
 server through which the request should be sent.  Or it can be a
 list of two values - a string denoting the proxy server and an
 integer denoting the port to use \(which will default to 80
-otherwise).  Defaults to *default-http-proxy*. 
+otherwise).  Defaults to *default-http-proxy*.
 PROXY-BASIC-AUTHORIZATION is used like
 BASIC-AUTHORIZATION, but for the proxy, and only if PROXY is
 true. If the host portion of the uri is present in the
@@ -819,8 +823,9 @@ PARAMETERS will not be used."
                                      (drakma-warn "Adding trailers from chunked encoding to HTTP headers.")
                                      (setq headers (nconc headers trailers)))))
                                (setq done t)
-                               (values (cond (want-stream (decode-flexi-stream headers http-stream))
-                                             (t body))
+                               (values (if want-stream
+                                           (decode-flexi-stream headers http-stream)
+                                           body)
                                        status-code
                                        headers
                                        uri
